@@ -252,7 +252,9 @@ void AttachmentControllerBase::Private::editSelectedAttachmentWith()
 void AttachmentControllerBase::Private::removeSelectedAttachments()
 {
     Q_ASSERT(selectedParts.count() >= 1);
-    for (const AttachmentPart::Ptr &part : qAsConst(selectedParts)) {
+    //We must store list, otherwise when we remove it changes selectedParts (as selection changed) => it will crash.
+    const AttachmentPart::List toRemove = selectedParts;
+    for (const AttachmentPart::Ptr &part : toRemove) {
         model->removeAttachment(part);
     }
 }
@@ -273,7 +275,7 @@ void AttachmentControllerBase::Private::reloadAttachment()
 {
     Q_ASSERT(selectedParts.count() == 1);
     AttachmentUpdateJob *ajob = new AttachmentUpdateJob(selectedParts.first(), q);
-    connect(ajob, SIGNAL(result(KJob*)), q, SLOT(updateJobResult(KJob*)));
+    connect(ajob, &AttachmentUpdateJob::result, q, [this](KJob *job) { updateJobResult(job); });
     ajob->start();
 }
 
@@ -488,40 +490,40 @@ void AttachmentControllerBase::createActions()
     connect(d->removeContextAction, &QAction::triggered, this, [this]() { d->removeSelectedAttachments(); });
 
     d->openContextAction = new QAction(i18nc("to open", "Open"), this);
-    connect(d->openContextAction, SIGNAL(triggered(bool)), this, SLOT(openSelectedAttachments()));
+    connect(d->openContextAction, &QAction::triggered, this, [this]() { d->openSelectedAttachments(); });
 
     d->viewContextAction = new QAction(i18nc("to view", "View"), this);
-    connect(d->viewContextAction, SIGNAL(triggered(bool)), this, SLOT(viewSelectedAttachments()));
+    connect(d->viewContextAction, &QAction::triggered, this, [this]() { d->viewSelectedAttachments(); });
 
     d->editContextAction = new QAction(i18nc("to edit", "Edit"), this);
-    connect(d->editContextAction, SIGNAL(triggered(bool)), this, SLOT(editSelectedAttachment()));
+    connect(d->editContextAction, &QAction::triggered, this, [this]() { d->editSelectedAttachment(); });
 
     d->editWithContextAction = new QAction(i18n("Edit With..."), this);
-    connect(d->editWithContextAction, SIGNAL(triggered(bool)), this, SLOT(editSelectedAttachmentWith()));
+    connect(d->editWithContextAction, &QAction::triggered, this, [this]() { d->editSelectedAttachmentWith(); });
 
     d->saveAsAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")),
                                   i18n("&Save Attachment As..."), this);
     d->saveAsContextAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")),
                                          i18n("Save As..."), this);
-    connect(d->saveAsAction, SIGNAL(triggered(bool)),
-            this, SLOT(saveSelectedAttachmentAs()));
-    connect(d->saveAsContextAction, SIGNAL(triggered(bool)),
-            this, SLOT(saveSelectedAttachmentAs()));
+    connect(d->saveAsAction, &QAction::triggered,
+            this, [this]() { d->saveSelectedAttachmentAs(); });
+    connect(d->saveAsContextAction, &QAction::triggered,
+            this, [this]() { d->saveSelectedAttachmentAs(); });
 
     d->propertiesAction = new QAction(i18n("Attachment Pr&operties..."), this);
     d->propertiesContextAction = new QAction(i18n("Properties"), this);
-    connect(d->propertiesAction, SIGNAL(triggered(bool)),
-            this, SLOT(selectedAttachmentProperties()));
-    connect(d->propertiesContextAction, SIGNAL(triggered(bool)),
-            this, SLOT(selectedAttachmentProperties()));
+    connect(d->propertiesAction, &QAction::triggered,
+            this, [this]() { d->selectedAttachmentProperties(); });
+    connect(d->propertiesContextAction, &QAction::triggered,
+            this, [this]() { d->selectedAttachmentProperties(); });
 
     d->selectAllAction = new QAction(i18n("Select All"), this);
     connect(d->selectAllAction, &QAction::triggered,
             this, &AttachmentControllerBase::selectedAllAttachment);
 
     d->reloadAttachmentAction = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Reload"), this);
-    connect(d->reloadAttachmentAction, SIGNAL(triggered(bool)),
-            this, SLOT(reloadAttachment()));
+    connect(d->reloadAttachmentAction, &QAction::triggered,
+            this, [this]() {d->reloadAttachment();});
 
     // Insert the actions into the composer window's menu.
     KActionCollection *collection = d->mActionCollection;
@@ -558,7 +560,7 @@ void AttachmentControllerBase::compressAttachment(const AttachmentPart::Ptr &par
         qCDebug(MESSAGECOMPOSER_LOG) << "Compressing part.";
 
         AttachmentCompressJob *ajob = new AttachmentCompressJob(part, this);
-        connect(ajob, SIGNAL(result(KJob*)), this, SLOT(compressJobResult(KJob*)));
+        connect(ajob, &AttachmentCompressJob::result, this, [this](KJob *job) { d->compressJobResult(job); });
         ajob->start();
     } else {
         qCDebug(MESSAGECOMPOSER_LOG) << "Uncompressing part.";
@@ -578,7 +580,7 @@ void AttachmentControllerBase::showContextMenu()
     Q_EMIT refreshSelection();
 
     const int numberOfParts(d->selectedParts.count());
-    QMenu *menu = new QMenu;
+    QMenu menu;
 
     const bool enableEditAction = (numberOfParts == 1)
                                   && (!d->selectedParts.first()->isMessageOrMessageCollection());
@@ -595,44 +597,43 @@ void AttachmentControllerBase::showContextMenu()
             if ((mimetype == QLatin1String("text/plain"))
                 || (mimetype == QLatin1String("image/png"))
                 || (mimetype == QLatin1String("image/jpeg"))
-                || parentMimeType.contains(QStringLiteral("text/plain"))
-                || parentMimeType.contains(QStringLiteral("image/png"))
-                || parentMimeType.contains(QStringLiteral("image/jpeg"))
+                || parentMimeType.contains(QLatin1String("text/plain"))
+                || parentMimeType.contains(QLatin1String("image/png"))
+                || parentMimeType.contains(QLatin1String("image/jpeg"))
                 ) {
-                menu->addAction(d->viewContextAction);
+                menu.addAction(d->viewContextAction);
             }
-            d->createOpenWithMenu(menu, d->selectedParts.first());
+            d->createOpenWithMenu(&menu, d->selectedParts.first());
         }
-        menu->addAction(d->openContextAction);
+        menu.addAction(d->openContextAction);
     }
     if (enableEditAction) {
-        menu->addAction(d->editWithContextAction);
-        menu->addAction(d->editContextAction);
+        menu.addAction(d->editWithContextAction);
+        menu.addAction(d->editContextAction);
     }
     if (numberOfParts > 0) {
-        menu->addAction(d->removeContextAction);
+        menu.addAction(d->removeContextAction);
     }
     if (numberOfParts == 1) {
         if (!d->selectedParts.first()->url().isEmpty()) {
-            menu->addAction(d->reloadAttachmentAction);
+            menu.addAction(d->reloadAttachmentAction);
         }
-        menu->addAction(d->saveAsContextAction);
-        menu->addSeparator();
-        menu->addAction(d->propertiesContextAction);
+        menu.addAction(d->saveAsContextAction);
+        menu.addSeparator();
+        menu.addAction(d->propertiesContextAction);
     }
 
     const int nbAttachment = d->model->rowCount();
     if (nbAttachment != numberOfParts) {
-        menu->addSeparator();
-        menu->addAction(d->selectAllAction);
+        menu.addSeparator();
+        menu.addAction(d->selectAllAction);
     }
     if (numberOfParts == 0) {
-        menu->addSeparator();
-        menu->addAction(d->addContextAction);
+        menu.addSeparator();
+        menu.addAction(d->addContextAction);
     }
 
-    menu->exec(QCursor::pos());
-    delete menu;
+    menu.exec(QCursor::pos());
 }
 
 void AttachmentControllerBase::slotOpenWithDialog()
@@ -716,8 +717,7 @@ void AttachmentControllerBase::viewAttachment(const AttachmentPart::Ptr &part)
     MessageComposer::Composer *composer = new MessageComposer::Composer;
     composer->globalPart()->setFallbackCharsetEnabled(true);
     MessageComposer::AttachmentJob *attachmentJob = new MessageComposer::AttachmentJob(part, composer);
-    connect(attachmentJob, SIGNAL(result(KJob*)),
-            this, SLOT(slotAttachmentContentCreated(KJob*)));
+    connect(attachmentJob, &AttachmentJob::result, this, [this](KJob *job) { d->slotAttachmentContentCreated(job); });
     attachmentJob->start();
 }
 
@@ -749,8 +749,8 @@ void AttachmentControllerBase::editAttachment(AttachmentPart::Ptr part, MessageV
         QUrl::fromLocalFile(tempFile->fileName()),
         QString::fromLatin1(part->mimeType()), openWithOption,
         this, d->wParent);
-    connect(watcher, SIGNAL(editDone(MessageViewer::EditorWatcher*)),
-            this, SLOT(editDone(MessageViewer::EditorWatcher*)));
+    connect(watcher, &MessageViewer::EditorWatcher::editDone,
+            this, [this](MessageViewer::EditorWatcher *watcher)  { d->editDone(watcher);});
 
     switch (watcher->start()) {
     case MessageViewer::EditorWatcher::NoError:
@@ -932,7 +932,7 @@ void AttachmentControllerBase::addAttachmentUrlSync(const QUrl &url)
 void AttachmentControllerBase::addAttachment(const QUrl &url)
 {
     MessageCore::AttachmentFromUrlBaseJob *ajob = MessageCore::AttachmentFromUrlUtils::createAttachmentJob(url, this);
-    connect(ajob, SIGNAL(result(KJob*)), this, SLOT(loadJobResult(KJob*)));
+    connect(ajob, &AttachmentFromUrlBaseJob::result, this, [this](KJob *job) { d->loadJobResult(job); });
     ajob->start();
 }
 
