@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,10 +21,11 @@
 #include "ui_imagescalingwidget.h"
 #include "settings/messagecomposersettings.h"
 
-#include <KComboBox>
 #include <KLocalizedString>
 #include <KMessageBox>
 
+#include <QButtonGroup>
+#include <QComboBox>
 #include <QImageWriter>
 #include <QWhatsThis>
 
@@ -33,26 +34,24 @@ class MessageComposer::ImageScalingWidgetPrivate
 {
 public:
     ImageScalingWidgetPrivate()
-        : ui(new Ui::ImageScalingWidget),
-          mSourceFilenameFilterGroup(nullptr),
-          mRecipientFilterGroup(nullptr),
-          mWasChanged(false)
+        : ui(new Ui::ImageScalingWidget)
     {
     }
+
     ~ImageScalingWidgetPrivate()
     {
         delete ui;
     }
 
-    Ui::ImageScalingWidget *ui;
-    QButtonGroup *mSourceFilenameFilterGroup;
-    QButtonGroup *mRecipientFilterGroup;
-    bool mWasChanged;
+    Ui::ImageScalingWidget *ui = nullptr;
+    QButtonGroup *mSourceFilenameFilterGroup = nullptr;
+    QButtonGroup *mRecipientFilterGroup = nullptr;
+    bool mWasChanged = false;
 };
 
 ImageScalingWidget::ImageScalingWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new MessageComposer::ImageScalingWidgetPrivate)
+    : QWidget(parent)
+    , d(new MessageComposer::ImageScalingWidgetPrivate)
 {
     d->ui->setupUi(this);
     initComboBox(d->ui->CBMaximumWidth);
@@ -73,11 +72,11 @@ ImageScalingWidget::ImageScalingWidget(QWidget *parent)
     connect(d->ui->skipImageSizeLower, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->imageSize, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
     connect(d->ui->pattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
-    connect(d->ui->CBMaximumWidth, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
-    connect(d->ui->CBMaximumHeight, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
-    connect(d->ui->CBMinimumWidth, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
-    connect(d->ui->CBMinimumHeight, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
-    connect(d->ui->WriteToImageFormat, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &ImageScalingWidget::changed);
+    connect(d->ui->CBMaximumWidth, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(d->ui->CBMaximumHeight, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(d->ui->CBMinimumWidth, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(d->ui->CBMinimumHeight, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(d->ui->WriteToImageFormat, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &ImageScalingWidget::changed);
     connect(d->ui->renameResizedImage, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->renameResizedImage, &QCheckBox::clicked, d->ui->renameResizedImagePattern, &KLineEdit::setEnabled);
     connect(d->ui->renameResizedImagePattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
@@ -118,18 +117,18 @@ ImageScalingWidget::~ImageScalingWidget()
 
 void ImageScalingWidget::slotHelpLinkClicked(const QString &)
 {
-    const QString help =
-        i18n("<qt>"
-             "<p>Here you can define image filename. "
-             "You can use:</p>"
-             "<ul>"
-             "<li>%t set current time</li>"
-             "<li>%d set current date</li>"
-             "<li>%n original filename</li>"
-             "<li>%e original extension</li>"
-             "<li>%x new extension</li>"
-             "</ul>"
-             "</qt>");
+    const QString help
+        = i18n("<qt>"
+               "<p>Here you can define image filename. "
+               "You can use:</p>"
+               "<ul>"
+               "<li>%t set current time</li>"
+               "<li>%d set current date</li>"
+               "<li>%n original filename</li>"
+               "<li>%e original extension</li>"
+               "<li>%x new extension</li>"
+               "</ul>"
+               "</qt>");
 
     QWhatsThis::showText(QCursor::pos(), help);
 }
@@ -142,16 +141,16 @@ void ImageScalingWidget::slotSourceFilterClicked(int button)
 
 void ImageScalingWidget::slotRecipientFilterClicked(int button)
 {
-    d->ui->resizeEmailsPattern->setEnabled((button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern) ||
-                                           (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern));
-    d->ui->doNotResizePattern->setEnabled((button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeEachEmailsContainsPattern) ||
-                                          (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern));
+    d->ui->resizeEmailsPattern->setEnabled((button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern)
+                                           || (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern));
+    d->ui->doNotResizePattern->setEnabled((button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeEachEmailsContainsPattern)
+                                          || (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern));
     Q_EMIT changed();
 }
 
 void ImageScalingWidget::slotComboboxChanged(int index)
 {
-    KComboBox *combo = qobject_cast< KComboBox * >(sender());
+    QComboBox *combo = qobject_cast< QComboBox * >(sender());
     if (combo) {
         const bool isCustom = combo->itemData(index) == -1;
         if (combo == d->ui->CBMaximumWidth) {
@@ -167,7 +166,7 @@ void ImageScalingWidget::slotComboboxChanged(int index)
     }
 }
 
-void ImageScalingWidget::initComboBox(KComboBox *combo)
+void ImageScalingWidget::initComboBox(QComboBox *combo)
 {
     const QList<int> size = { 240, 320, 512, 640, 800, 1024, 1600, 2048 };
     for (int val : size) {
@@ -299,8 +298,8 @@ void ImageScalingWidget::updateEmailsFilterTypeSettings()
 void ImageScalingWidget::writeConfig()
 {
     if (d->ui->EnlargeImageToMinimum->isChecked() && d->ui->ReduceImageToMaximum->isChecked()) {
-        if ((d->ui->customMinimumWidth->value() >= d->ui->customMaximumWidth->value()) ||
-                (d->ui->customMinimumHeight->value() >= d->ui->customMaximumHeight->value())) {
+        if ((d->ui->customMinimumWidth->value() >= d->ui->customMaximumWidth->value())
+            || (d->ui->customMinimumHeight->value() >= d->ui->customMaximumHeight->value())) {
             KMessageBox::error(this, i18n("Please verify minimum and maximum values."), i18n("Error in minimum Maximum value"));
             return;
         }
@@ -348,4 +347,3 @@ void ImageScalingWidget::resetToDefault()
     updateSettings();
     MessageComposer::MessageComposerSettings::self()->useDefaults(bUseDefaults);
 }
-
