@@ -25,8 +25,7 @@
 
 #include <kjob.h>
 #include <QStringList>
-namespace MessageComposer
-{
+namespace MessageComposer {
 /**
  * @short A job to expand a distribution list to its member email addresses.
  */
@@ -46,7 +45,7 @@ public:
     /**
      * Destroys the distribution list expand job.
      */
-    ~DistributionListExpandJob();
+    ~DistributionListExpandJob() override;
 
     /**
      * Starts the job.
