@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,18 +25,16 @@ class MessageComposer::PluginEditorCheckBeforeSendPrivate
 {
 public:
     PluginEditorCheckBeforeSendPrivate()
-        : mIsEnabled(false)
     {
-
     }
-    bool mIsEnabled;
+
+    bool mIsEnabled = false;
 };
 
 PluginEditorCheckBeforeSend::PluginEditorCheckBeforeSend(QObject *parent)
-    : QObject(parent),
-      d(new MessageComposer::PluginEditorCheckBeforeSendPrivate)
+    : QObject(parent)
+    , d(new MessageComposer::PluginEditorCheckBeforeSendPrivate)
 {
-
 }
 
 PluginEditorCheckBeforeSend::~PluginEditorCheckBeforeSend()
