@@ -30,9 +30,7 @@
 
 #include <KComboBox>
 
-namespace MessageComposer
-{
-
+namespace MessageComposer {
 class RecipientComboBox : public KComboBox
 {
     Q_OBJECT
@@ -66,7 +64,9 @@ class MESSAGECOMPOSER_EXPORT RecipientLineNG : public KPIM::MultiplyingLine
     Q_OBJECT
 public:
     explicit RecipientLineNG(QWidget *parent);
-    virtual ~RecipientLineNG() {}
+    virtual ~RecipientLineNG()
+    {
+    }
 
     void activate() override;
     bool isActive() const override;
@@ -128,16 +128,13 @@ protected:
 private:
     void dataFromFields();
     void fieldsFromData();
-    RecipientComboBox *mCombo;
-    RecipientLineEdit *mEdit;
+    void slotAddRecipient(const QString &);
+    RecipientComboBox *mCombo = nullptr;
+    RecipientLineEdit *mEdit = nullptr;
     int mRecipientsCount;
     bool mModified;
     QSharedPointer<Recipient> mData;
-
-private Q_SLOTS:
-    void slotAddRecipient(const QString &);
 };
-
 }
 
 #endif // RECIPIENTLINE_H
