@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,20 +17,17 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #ifndef RECIPIENTSEDITORMANAGER_H
 #define RECIPIENTSEDITORMANAGER_H
 
 #include <QObject>
 #include "messagecomposer_export.h"
 
-namespace Akonadi
-{
+namespace Akonadi {
 class EmailAddressSelectionModel;
 }
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class MESSAGECOMPOSER_EXPORT RecipientsEditorManager : public QObject
 {
     Q_OBJECT
@@ -42,7 +39,7 @@ public:
     Akonadi::EmailAddressSelectionModel *model();
 
 private:
-    Akonadi::EmailAddressSelectionModel *mModel;
+    Akonadi::EmailAddressSelectionModel *mModel = nullptr;
 };
 }
 
