@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,10 +24,8 @@
 #include "messagecore_debug.h"
 
 #include <QMimeDatabase>
-#include <QMimeType>
 
-namespace MessageCore
-{
+namespace MessageCore {
 MessageCore::AttachmentFromUrlBaseJob *AttachmentFromUrlUtils::createAttachmentJob(const QUrl &url, QObject *parent)
 {
     MessageCore::AttachmentFromUrlBaseJob *ajob = nullptr;
@@ -45,4 +43,3 @@ MessageCore::AttachmentFromUrlBaseJob *AttachmentFromUrlUtils::createAttachmentJ
     return ajob;
 }
 }
-
