@@ -18,34 +18,28 @@
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_WIDGETBASE_H__
-#define __MESSAGELIST_CORE_WIDGETBASE_H__
+#ifndef MESSAGELIST_CORE_WIDGETBASE_H
+#define MESSAGELIST_CORE_WIDGETBASE_H
 
 #include <QWidget>
 #include <QString>
 #include <QList>
 
-#include <core/enums.h>
-#include <core/sortorder.h>
-#include <core/widgets/quicksearchline.h>
+#include <MessageList/Enums>
+#include <MessageList/QuickSearchLine>
 
 class QLineEdit;
 class QActionGroup;
 class KComboBox;
 class QMenu;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Collection;
 class MessageStatus;
 }
 
-namespace MessageList
-{
-
-namespace Core
-{
-
+namespace MessageList {
+namespace Core {
 class GroupHeaderItem;
 class MessageItem;
 class StorageModel;
@@ -73,24 +67,24 @@ public:
     void setStorageModel(StorageModel *storageModel, PreSelectionMode preSelectionMode = PreSelectLastSelected);
 
     /**
-    * Returns the StorageModel currently set. May be 0.
+    * Returns the StorageModel currently set. May be nullptr.
     */
     StorageModel *storageModel() const;
 
     /**
-    * Returns the search line of this widget. Can be 0 if the quick search
+    * Returns the search line of this widget. Can be nullptr if the quick search
     * is disabled in the global configuration.
     */
     QLineEdit *quickSearch() const;
 
     /**
-    * Returns the View attached to this Widget. Never 0.
+    * Returns the View attached to this Widget. Never nullptr.
     */
     View *view() const;
 
     /**
     * Returns the current MessageItem in the current folder.
-    * May return 0 if there is no current message or no current folder.
+    * May return nullptr if there is no current message or no current folder.
     */
     Core::MessageItem *currentMessageItem() const;
 
@@ -128,6 +122,7 @@ public:
     * Sets the current folder.
     */
     void setCurrentFolder(const Akonadi::Collection &collection);
+    Akonadi::Collection currentFolder() const;
 
     void saveCurrentSelection();
 
@@ -221,16 +216,6 @@ protected:
     */
     virtual void viewMessageStatusChangeRequest(MessageItem *msg, Akonadi::MessageStatus set, Akonadi::MessageStatus clear);
 
-    /**
-    * This is called by View to signal a start of a (possibly lengthy) job batch.
-    */
-    virtual void viewJobBatchStarted();
-
-    /**
-    * This is called by View to signal the end of a (possibly lengthy) job batch.
-    */
-    virtual void viewJobBatchTerminated();
-
     void tagIdSelected(const QVariant &data);
 
 Q_SIGNALS:
@@ -278,10 +263,7 @@ private:
     class Private;
     Private *const d;
 };
-
 } // namespace Core
-
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_WIDGET_H__
-
+#endif //!__MESSAGELIST_CORE_WIDGET_H
