@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
@@ -20,7 +20,7 @@
 
 #include "quicksearchline.h"
 #include "messagelistsettings.h"
-
+#include <KStringHandler>
 #include <Akonadi/KMime/MessageStatus>
 
 #include "searchlinestatus.h"
@@ -86,7 +86,7 @@ void QuickSearchLine::slotSearchEditTextEdited(const QString &text)
         minimumStringLength = 5;
     }
     if (!text.trimmed().isEmpty()) {
-        if (text.length() >= minimumStringLength) {
+        if (KStringHandler::logicalLength(text) > minimumStringLength) {
             Q_EMIT searchEditTextEdited(text);
         }
     } else {
