@@ -18,7 +18,6 @@
 
 #include "pane.h"
 
-
 #include <KActionCollection>
 #include <KActionMenu>
 #include <QIcon>
@@ -46,29 +45,28 @@
 #include "core/model.h"
 #include "messagelistutil_p.h"
 
-namespace MessageList
-{
-
+namespace MessageList {
 class Q_DECL_HIDDEN Pane::Private
 {
 public:
     Private(Pane *owner)
-        : q(owner),
-          mXmlGuiClient(nullptr),
-          mActionMenu(nullptr),
-          mModel(nullptr),
-          mSelectionModel(nullptr),
-          mPreSelectionMode(Core::PreSelectLastSelected),
-          mNewTabButton(nullptr),
-          mCloseTabButton(nullptr),
-          mCloseTabAction(nullptr),
-          mActivateNextTabAction(nullptr),
-          mActivatePreviousTabAction(nullptr),
-          mMoveTabLeftAction(nullptr),
-          mMoveTabRightAction(nullptr),
-          mPreferEmptyTab(false),
-          mMaxTabCreated(0)
-    { }
+        : q(owner)
+        , mXmlGuiClient(nullptr)
+        , mActionMenu(nullptr)
+        , mModel(nullptr)
+        , mSelectionModel(nullptr)
+        , mPreSelectionMode(Core::PreSelectLastSelected)
+        , mNewTabButton(nullptr)
+        , mCloseTabButton(nullptr)
+        , mCloseTabAction(nullptr)
+        , mActivateNextTabAction(nullptr)
+        , mActivatePreviousTabAction(nullptr)
+        , mMoveTabLeftAction(nullptr)
+        , mMoveTabRightAction(nullptr)
+        , mPreferEmptyTab(false)
+        , mMaxTabCreated(0)
+    {
+    }
 
     void onSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
     void onNewTabClicked();
@@ -92,34 +90,34 @@ public:
 
     Pane *const q;
 
-    KXMLGUIClient *mXmlGuiClient;
-    KActionMenu *mActionMenu;
+    KXMLGUIClient *mXmlGuiClient = nullptr;
+    KActionMenu *mActionMenu = nullptr;
 
-    QAbstractItemModel *mModel;
-    QItemSelectionModel *mSelectionModel;
+    QAbstractItemModel *mModel = nullptr;
+    QItemSelectionModel *mSelectionModel = nullptr;
     Core::PreSelectionMode mPreSelectionMode;
 
     QHash<Widget *, QItemSelectionModel *> mWidgetSelectionHash;
     QVector<const QAbstractProxyModel *> mProxyStack;
 
-    QToolButton *mNewTabButton;
-    QToolButton *mCloseTabButton;
-    QAction *mCloseTabAction;
-    QAction *mActivateNextTabAction;
-    QAction *mActivatePreviousTabAction;
-    QAction *mMoveTabLeftAction;
-    QAction *mMoveTabRightAction;
+    QToolButton *mNewTabButton = nullptr;
+    QToolButton *mCloseTabButton = nullptr;
+    QAction *mCloseTabAction = nullptr;
+    QAction *mActivateNextTabAction = nullptr;
+    QAction *mActivatePreviousTabAction = nullptr;
+    QAction *mMoveTabLeftAction = nullptr;
+    QAction *mMoveTabRightAction = nullptr;
     bool mPreferEmptyTab;
     int mMaxTabCreated;
 };
-
 } // namespace MessageList
 
 using namespace Akonadi;
 using namespace MessageList;
 
 Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent)
-    : QTabWidget(parent), d(new Private(this))
+    : QTabWidget(parent)
+    , d(new Private(this))
 {
     setDocumentMode(true);
     d->mModel = model;
@@ -152,8 +150,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     d->mNewTabButton->setAccessibleName(i18n("New tab"));
 #endif
     setCornerWidget(d->mNewTabButton, Qt::TopLeftCorner);
-    connect(d->mNewTabButton, SIGNAL(clicked()),
-            SLOT(onNewTabClicked()));
+    connect(d->mNewTabButton, &QToolButton::clicked, this, [this]() { d->onNewTabClicked(); });
 
     d->mCloseTabButton = new QToolButton(this);
     d->mCloseTabButton->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
@@ -163,23 +160,22 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     d->mCloseTabButton->setAccessibleName(i18n("Close tab"));
 #endif
     setCornerWidget(d->mCloseTabButton, Qt::TopRightCorner);
-    connect(d->mCloseTabButton, SIGNAL(clicked()),
-            SLOT(onCloseTabClicked()));
+    connect(d->mCloseTabButton, &QToolButton::clicked,
+            this, [this]() {d->onCloseTabClicked(); });
 
     setTabsClosable(true);
-    connect(this, SIGNAL(tabCloseRequested(int)), this, SLOT(slotTabCloseRequested(int)));
+    connect(this, &Pane::tabCloseRequested, this, [this](int index) { d->slotTabCloseRequested(index);});
 
     readConfig(restoreSession);
     setMovable(true);
 
     connect(d->mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             this, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
-    connect(this, SIGNAL(currentChanged(int)),
-            this, SLOT(onCurrentTabChanged()));
+    connect(this, &Pane::currentChanged,
+            this, [this]() { d->onCurrentTabChanged(); });
 
     setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(onTabContextMenuRequest(QPoint)));
+    connect(this, &Pane::customContextMenuRequested, this, [this](const QPoint &point) { d->onTabContextMenuRequest(point);});
 
     connect(MessageListSettings::self(), SIGNAL(configChanged()),
             this, SLOT(updateTabControls()));
@@ -192,6 +188,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
 
 Pane::~Pane()
 {
+    saveCurrentSelection();
     writeConfig(true);
     delete d;
 }
@@ -203,7 +200,7 @@ void Pane::Private::addActivateTabAction(int i)
     QAction *action = new QAction(i18n("Activate Tab %1", i), q);
     mXmlGuiClient->actionCollection()->addAction(actionname, action);
     mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(QStringLiteral("Alt+%1").arg(i)));
-    connect(action, SIGNAL(triggered(bool)), q, SLOT(activateTab()));
+    connect(action, &QAction::triggered, q, [this]() { activateTab(); });
 }
 
 void Pane::Private::slotTabCloseRequested(int index)
@@ -223,11 +220,13 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
     showHideQuicksearch->setChecked(MessageListSettings::showQuickSearch());
 
     d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("show_quick_search"), showHideQuicksearch);
-    connect(showHideQuicksearch, SIGNAL(triggered(bool)), this, SLOT(changeQuicksearchVisibility(bool)));
+    connect(showHideQuicksearch, &KToggleAction::triggered, this, [this](bool state) { d->changeQuicksearchVisibility(state); });
 
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->setXmlGuiClient(d->mXmlGuiClient);
+        if (w) {
+            w->setXmlGuiClient(d->mXmlGuiClient);
+        }
     }
 
     // Setup "View->Message List" actions.
@@ -244,7 +243,7 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         QAction *action = new QAction(i18n("Create New Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("create_new_tab"), action);
         d->mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_O));
-        connect(action, SIGNAL(triggered(bool)), SLOT(onNewTabClicked()));
+        connect(action, &QAction::triggered, this, [this]() { d->onNewTabClicked(); });
         d->mActionMenu->addAction(action);
 
         d->mMaxTabCreated = count();
@@ -255,36 +254,33 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         d->mCloseTabAction = new QAction(i18n("Close Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("close_current_tab"), d->mCloseTabAction);
         d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mCloseTabAction, QList<QKeySequence>() << QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_W) << QKeySequence(Qt::CTRL + Qt::Key_W));
-        connect(d->mCloseTabAction, SIGNAL(triggered(bool)), SLOT(onCloseTabClicked()));
+        connect(d->mCloseTabAction, &QAction::triggered, this, [this]() { d->onCloseTabClicked(); });
         d->mActionMenu->addAction(d->mCloseTabAction);
         d->mCloseTabAction->setEnabled(false);
 
         d->mActivateNextTabAction = new QAction(i18n("Activate Next Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("activate_next_tab"), d->mActivateNextTabAction);
         d->mActivateNextTabAction->setEnabled(false);
-        connect(d->mActivateNextTabAction, SIGNAL(triggered(bool)), SLOT(activateNextTab()));
+        connect(d->mActivateNextTabAction, &QAction::triggered, [this]() { d->activateNextTab(); });
 
         d->mActivatePreviousTabAction = new QAction(i18n("Activate Previous Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("activate_previous_tab"), d->mActivatePreviousTabAction);
         d->mActivatePreviousTabAction->setEnabled(false);
-        connect(d->mActivatePreviousTabAction, SIGNAL(triggered(bool)), SLOT(activatePreviousTab()));
+        connect(d->mActivatePreviousTabAction, &QAction::triggered, this, [this]() { d->activatePreviousTab(); });
 
         d->mMoveTabLeftAction = new QAction(i18n("Move Tab Left"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("move_tab_left"), d->mMoveTabLeftAction);
         d->mMoveTabLeftAction->setEnabled(false);
-        connect(d->mMoveTabLeftAction, SIGNAL(triggered(bool)), SLOT(moveTabLeft()));
+        connect(d->mMoveTabLeftAction, &QAction::triggered, this, [this]() { d->moveTabLeft(); });
 
         d->mMoveTabRightAction = new QAction(i18n("Move Tab Right"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("move_tab_right"), d->mMoveTabRightAction);
         d->mMoveTabRightAction->setEnabled(false);
-        connect(d->mMoveTabRightAction, SIGNAL(triggered(bool)), SLOT(moveTabRight()));
+        connect(d->mMoveTabRightAction, &QAction::triggered, this, [this]() { d->moveTabRight(); });
     }
 }
 
-bool Pane::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
-                                 MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                                 bool centerItem,
-                                 bool loop)
+bool Pane::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
 {
     Widget *w = static_cast<Widget *>(currentWidget());
 
@@ -299,10 +295,7 @@ bool Pane::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTyp
     }
 }
 
-bool Pane::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
-                                     MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                                     bool centerItem,
-                                     bool loop)
+bool Pane::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
 {
     Widget *w = static_cast<Widget *>(currentWidget());
 
@@ -514,7 +507,6 @@ void Pane::Private::onSelectionChanged(const QItemSelection &selected, const QIt
 
         connect(mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
                 q, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
-
     }
 }
 
@@ -534,7 +526,6 @@ void Pane::Private::moveTabRight()
     } else {
         moveTabBackward();
     }
-
 }
 
 void Pane::Private::moveTabLeft()
@@ -548,7 +539,6 @@ void Pane::Private::moveTabLeft()
     } else {
         moveTabForward();
     }
-
 }
 
 void Pane::Private::moveTabForward()
@@ -617,6 +607,11 @@ void Pane::Private::closeTab(QWidget *w)
         return;
     }
 
+    Widget *wWidget = qobject_cast<Widget *>(w);
+    if (wWidget) {
+        wWidget->saveCurrentSelection();
+    }
+
     delete w;
     updateTabControls();
 }
@@ -625,7 +620,9 @@ void Pane::Private::changeQuicksearchVisibility(bool show)
 {
     for (int i = 0; i < q->count(); ++i) {
         Widget *w = qobject_cast<Widget *>(q->widget(i));
-        w->changeQuicksearchVisibility(show);
+        if (w) {
+            w->changeQuicksearchVisibility(show);
+        }
     }
 }
 
@@ -695,10 +692,13 @@ void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
             }
 
             Widget *other = qobject_cast<Widget *>(q->widget(i));
-            widgets << other;
+            if (other) {
+                widgets << other;
+            }
         }
 
         foreach (Widget *other, widgets) {
+            other->saveCurrentSelection();
             delete other;
         }
 
@@ -713,6 +713,15 @@ MessageList::StorageModel *Pane::createStorageModel(QAbstractItemModel *model, Q
     return new MessageList::StorageModel(model, selectionModel, parent);
 }
 
+Akonadi::Collection Pane::currentFolder() const
+{
+    Widget *w = static_cast<Widget *>(currentWidget());
+    if (w) {
+        return w->currentCollection();
+    }
+    return {};
+}
+
 void Pane::setCurrentFolder(const Akonadi::Collection &collection, bool, Core::PreSelectionMode preSelectionMode, const QString &overrideLabel)
 {
     d->mPreSelectionMode = preSelectionMode;
@@ -733,7 +742,7 @@ void Pane::updateTabIconText(const Akonadi::Collection &collection, const QStrin
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        if (w->currentCollection() == collection) {
+        if (w && (w->currentCollection() == collection)) {
             const int index = indexOf(w);
             setTabText(index, label);
             setTabIcon(index, icon);
@@ -982,10 +991,7 @@ bool Pane::selectionEmpty() const
     return false;
 }
 
-bool Pane::getSelectionStats(Akonadi::Item::List &selectedItems,
-                             Akonadi::Item::List &selectedVisibleItems,
-                             bool *allSelectedBelongToSameThread,
-                             bool includeCollapsedChildren) const
+bool Pane::getSelectionStats(Akonadi::Item::List &selectedItems, Akonadi::Item::List &selectedVisibleItems, bool *allSelectedBelongToSameThread, bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
     if (w == nullptr) {
@@ -993,9 +999,9 @@ bool Pane::getSelectionStats(Akonadi::Item::List &selectedItems,
     }
 
     return w->getSelectionStats(
-               selectedItems, selectedVisibleItems,
-               allSelectedBelongToSameThread, includeCollapsedChildren
-           );
+        selectedItems, selectedVisibleItems,
+        allSelectedBelongToSameThread, includeCollapsedChildren
+        );
 }
 
 MessageList::Core::MessageItemSetReference Pane::selectionAsPersistentSet(bool includeCollapsedChildren) const
@@ -1061,7 +1067,9 @@ void Pane::saveCurrentSelection()
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->saveCurrentSelection();
+        if (w) {
+            w->saveCurrentSelection();
+        }
     }
 }
 
@@ -1069,7 +1077,9 @@ void Pane::updateTagComboBox()
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->populateStatusFilterCombo();
+        if (w) {
+            w->populateStatusFilterCombo();
+        }
     }
 }
 
@@ -1089,9 +1099,11 @@ void Pane::writeConfig(bool restoreSession)
 
         for (int i = 0; i < count(); ++i) {
             Widget *w = qobject_cast<Widget *>(widget(i));
-            KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(i));
-            grp.writeEntry(QStringLiteral("collectionId"), w->currentCollection().id());
-            grp.writeEntry(QStringLiteral("HeaderState"), w->view()->header()->saveState());
+            if (w) {
+                KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(i));
+                grp.writeEntry(QStringLiteral("collectionId"), w->currentCollection().id());
+                grp.writeEntry(QStringLiteral("HeaderState"), w->view()->header()->saveState());
+            }
         }
     }
     conf.sync();
@@ -1137,7 +1149,9 @@ void Pane::restoreHeaderSettings(int index)
     KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(index));
     if (grp.exists()) {
         Widget *w = qobject_cast<Widget *>(widget(index));
-        w->view()->header()->restoreState(grp.readEntry(QStringLiteral("HeaderState"), QByteArray()));
+        if (w) {
+            w->view()->header()->restoreState(grp.readEntry(QStringLiteral("HeaderState"), QByteArray()));
+        }
     }
 }
 
@@ -1184,7 +1198,9 @@ void Pane::populateStatusFilterCombo()
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->populateStatusFilterCombo();
+        if (w) {
+            w->populateStatusFilterCombo();
+        }
     }
 }
 
