@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,20 +35,14 @@ class MESSAGEVIEWER_EXPORT GrantleeHeaderFormatter
 public:
     struct GrantleeHeaderFormatterSettings {
         GrantleeHeaderFormatterSettings()
-            : isPrinting(false)
-            , style(nullptr)
-            , message(nullptr)
-            , showMailAction(true)
-            , showEmoticons(true)
         {
         }
 
         GrantleeTheme::Theme theme;
-        bool isPrinting;
-        mutable const MessageViewer::HeaderStyle *style;
-        KMime::Message *message;
-        bool showMailAction;
-        bool showEmoticons;
+        bool isPrinting = false;
+        mutable const MessageViewer::HeaderStyle *style = nullptr;
+        KMime::Message *message = nullptr;
+        bool showEmoticons = true;
     };
 
     explicit GrantleeHeaderFormatter();
@@ -56,14 +50,11 @@ public:
 
     QString toHtml(const GrantleeHeaderFormatterSettings &settings) const;
 
-    QString toHtml(const QStringList &displayExtraHeaders, const QString &absolutPath,
-                   const QString &filename, const MessageViewer::HeaderStyle *style,
-                   KMime::Message *message, bool isPrinting) const;
+    QString toHtml(const QStringList &displayExtraHeaders, const QString &absolutPath, const QString &filename, const MessageViewer::HeaderStyle *style, KMime::Message *message,
+                   bool isPrinting) const;
 private:
-    QString format(const QString &absolutePath, const Grantlee::Template &headerTemplate,
-                   const QStringList &displayExtraHeaders, bool isPrinting,
-                   const MessageViewer::HeaderStyle *style, KMime::Message *message,
-                   bool showMailAction = true, bool showEmoticons = true) const;
+    QString format(const QString &absolutePath, const Grantlee::Template &headerTemplate, const QStringList &displayExtraHeaders, bool isPrinting, const MessageViewer::HeaderStyle *style,
+                   KMime::Message *message, bool showEmoticons = true) const;
     class Private;
     Private *const d;
 };
