@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,21 +22,20 @@
 
 #include "messageviewer/headerstyle.h"
 
-namespace MessageViewer
-{
+namespace MessageViewer {
 class GrantleeHeaderStylePrivate;
 class MESSAGEVIEWER_EXPORT GrantleeHeaderStyle : public HeaderStyle
 {
 public:
     GrantleeHeaderStyle();
-    ~GrantleeHeaderStyle();
+    ~GrantleeHeaderStyle() override;
 
 public:
-    const char *name() const Q_DECL_OVERRIDE;
+    const char *name() const override;
 
-    QString format(KMime::Message *message) const Q_DECL_OVERRIDE;
+    QString format(KMime::Message *message) const override;
 
-    bool hasAttachmentQuickList() const Q_DECL_OVERRIDE;
+    bool hasAttachmentQuickList() const override;
 
     bool showMailAction() const;
     void setShowMailAction(bool showAction);
