@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -42,7 +42,7 @@ public:
     QStringList mExtraDisplay;
     QString mAbsolutePath;
     QString mMainFilename;
-    GrantleeHeaderFormatter *mGrantleeFormatter;
+    GrantleeHeaderFormatter *mGrantleeFormatter = nullptr;
 };
 
 GrantleeHeaderTestStyle::GrantleeHeaderTestStyle()
