@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,19 +22,18 @@
 
 #include "messageviewer/headerstyle.h"
 #include "messageviewer_export.h"
-namespace MessageViewer
-{
+namespace MessageViewer {
 class PlainHeaderStylePrivate;
 class MESSAGEVIEWER_EXPORT PlainHeaderStyle : public HeaderStyle
 {
 public:
     PlainHeaderStyle();
-    ~PlainHeaderStyle();
+    ~PlainHeaderStyle() override;
 
 public:
-    const char *name() const Q_DECL_OVERRIDE;
+    const char *name() const override;
 
-    QString format(KMime::Message *message) const Q_DECL_OVERRIDE;
+    QString format(KMime::Message *message) const override;
 
 private:
     PlainHeaderStylePrivate *const d;
