@@ -29,8 +29,8 @@
     your version.
 */
 
-#ifndef __KMAIL_INTERFACES_URLHANDLER_H__
-#define __KMAIL_INTERFACES_URLHANDLER_H__
+#ifndef KMAIL_INTERFACES_URLHANDLER_H
+#define KMAIL_INTERFACES_URLHANDLER_H
 
 #include <QUrl>
 
@@ -71,8 +71,7 @@ public:
       * @return true if the right-click was handled by this
       * URLHandler, false otherwise.
       */
-    virtual bool handleContextMenuRequest(const QUrl &url, const QPoint &p,
-                                          MessageViewer::ViewerPrivate *w) const = 0;
+    virtual bool handleContextMenuRequest(const QUrl &url, const QPoint &p, MessageViewer::ViewerPrivate *w) const = 0;
 
     /**
       * Called when hovering over a link.
@@ -117,4 +116,4 @@ public:
 };
 }
 
-#endif // __KMAIL_INTERFACES_URLHANDLER_H__
+#endif // KMAIL_INTERFACES_URLHANDLER_H
