@@ -17,21 +17,22 @@
    02110-1301, USA.
 */
 
-#ifndef __MIMETREEPARSER_HTMLBLOCK_H__
-#define __MIMETREEPARSER_HTMLBLOCK_H__
+#ifndef MIMETREEPARSER_HTMLBLOCK_H
+#define MIMETREEPARSER_HTMLBLOCK_H
+
+#include "messageviewer_export.h"
 
 #include <QString>
 #include <QSharedPointer>
-#include <QVector>
 
 namespace KMime {
 class Content;
 }
 
-namespace MimeTreeParser {
+namespace MessageViewer {
 class HtmlWriter;
 
-class HTMLBlock
+class MESSAGEVIEWER_EXPORT HTMLBlock
 {
 public:
     typedef QSharedPointer<HTMLBlock> Ptr;
@@ -54,10 +55,10 @@ private:
 // The attachment mark is a div that is placed around the attchment. It is used for drawing
 // a yellow border around the attachment when scrolling to it. When scrolling to it, the border
 // color of the div is changed, see KMReaderWin::scrollToAttachment().
-class AttachmentMarkBlock : public HTMLBlock
+class MESSAGEVIEWER_EXPORT AttachmentMarkBlock : public HTMLBlock
 {
 public:
-    AttachmentMarkBlock(MimeTreeParser::HtmlWriter *writer, KMime::Content *node);
+    AttachmentMarkBlock(HtmlWriter *writer, KMime::Content *node);
     virtual ~AttachmentMarkBlock();
 
 protected:
@@ -68,8 +69,8 @@ private:
     void internalEnter();
     void internalExit();
 
-    KMime::Content *mNode;
-    HtmlWriter *mWriter;
+    KMime::Content *mNode = nullptr;
+    HtmlWriter *mWriter = nullptr;
 };
 
 // Make sure the whole content is relative, so that nothing is painted over the header
@@ -78,7 +79,7 @@ private:
 class RootBlock : public HTMLBlock
 {
 public:
-    RootBlock(MimeTreeParser::HtmlWriter *writer);
+    RootBlock(HtmlWriter *writer);
     virtual ~RootBlock();
 
 protected:
@@ -89,7 +90,7 @@ private:
     void internalEnter();
     void internalExit();
 
-    HtmlWriter *mWriter;
+    HtmlWriter *mWriter = nullptr;
 };
 }
-#endif //__MIMETREEPARSER_HTMLBLOCK_H__
+#endif //__MIMETREEPARSER_HTMLBLOCK_H
