@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -23,15 +23,14 @@
 
 #include <QObject>
 #include "messageviewer_export.h"
-namespace MessageViewer
-{
+namespace MessageViewer {
 class ScamCheckShortUrl;
 class ScamCheckShortUrlManagerPrivate;
 class MESSAGEVIEWER_EXPORT ScamCheckShortUrlManager : public QObject
 {
     Q_OBJECT
 public:
-    explicit ScamCheckShortUrlManager(QObject *parent = Q_NULLPTR);
+    explicit ScamCheckShortUrlManager(QObject *parent = nullptr);
     ~ScamCheckShortUrlManager();
     static ScamCheckShortUrlManager *self();
     ScamCheckShortUrl *scamCheckShortUrl() const;
