@@ -128,10 +128,11 @@ KMime::Content::List Util::allContents(const KMime::Content *message)
     return result;
 }
 
-bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, QUrl &currentFolder)
+bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, QList<QUrl> &urlList)
 {
     QUrl url, dirUrl;
     QString recentDirClass;
+    QUrl currentFolder;
     const bool multiple = (contents.count() > 1);
     if (multiple) {
         // get the dir
@@ -268,6 +269,8 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
                 const bool result = saveContent(parent, content, curUrl);
                 if (!result) {
                     globalResult = result;
+                } else {
+                    urlList.append(curUrl);
                 }
             }
         }
@@ -422,23 +425,19 @@ bool Util::saveContent(QWidget *parent, KMime::Content *content, const QUrl &url
     return true;
 }
 
-bool Util::saveAttachments(const KMime::Content::List &contents, QWidget *parent, QUrl &currentFolder)
+bool Util::saveAttachments(const KMime::Content::List &contents, QWidget *parent, QList<QUrl> &urlList)
 {
     if (contents.isEmpty()) {
         KMessageBox::information(parent, i18n("Found no attachments to save."));
         return false;
     }
 
-    return Util::saveContents(parent, contents, currentFolder);
+    return Util::saveContents(parent, contents, urlList);
 }
 
-bool Util::saveMessageInMbox(const Akonadi::Item::List &retrievedMsgs, QWidget *parent, bool appendMessages)
+QString Util::generateMboxFileName(const Akonadi::Item &msgBase)
 {
     QString fileName;
-    if (retrievedMsgs.isEmpty()) {
-        return true;
-    }
-    const Akonadi::Item msgBase = retrievedMsgs.first();
 
     if (msgBase.hasPayload<KMime::Message::Ptr>()) {
         fileName
@@ -454,6 +453,16 @@ bool Util::saveMessageInMbox(const Akonadi::Item::List &retrievedMsgs, QWidget *
     if (!fileName.endsWith(QLatin1String(".mbox"))) {
         fileName += QLatin1String(".mbox");
     }
+    return fileName;
+}
+
+bool Util::saveMessageInMboxAndGetUrl(QUrl &url, const Akonadi::Item::List &retrievedMsgs, QWidget *parent, bool appendMessages)
+{
+    if (retrievedMsgs.isEmpty()) {
+        return false;
+    }
+    const Akonadi::Item msgBase = retrievedMsgs.first();
+    QString fileName = generateMboxFileName(msgBase);
 
     const QString filter = i18n("email messages (*.mbox);;all files (*)");
 
@@ -500,15 +509,22 @@ bool Util::saveMessageInMbox(const Akonadi::Item::List &retrievedMsgs, QWidget *
                                i18n("Error saving message"));
             return false;
         }
-        QUrl url = QUrl::fromLocalFile(saveFileName);
-        if (url.isLocalFile()) {
-            KRecentDirs::add(fileClass, url.adjusted(
+        QUrl localUrl = QUrl::fromLocalFile(saveFileName);
+        if (localUrl.isLocalFile()) {
+            KRecentDirs::add(fileClass, localUrl.adjusted(
                                  QUrl::RemoveFilename | QUrl::StripTrailingSlash).path());
         }
+        url = localUrl;
     }
     return true;
 }
 
+bool Util::saveMessageInMbox(const Akonadi::Item::List &retrievedMsgs, QWidget *parent, bool appendMessages)
+{
+    QUrl url;
+    return saveMessageInMboxAndGetUrl(url, retrievedMsgs, parent, appendMessages);
+}
+
 QAction *Util::createAppAction(const KService::Ptr &service, bool singleOffer, QActionGroup *actionGroup, QObject *parent)
 {
     QString actionName(service->name().replace(QLatin1Char('&'), QStringLiteral("&&")));
