@@ -18,15 +18,16 @@
 */
 
 #include "objecttreeemptysource.h"
+#include "viewer/attachmentstrategy.h"
 #include "viewer/viewer_p.h"
 #include "viewer/csshelperbase.h"
 
-#include <MimeTreeParser/AttachmentStrategy>
 #include <MimeTreeParser/BodyPartFormatter>
+#include <MimeTreeParser/BodyPartFormatterFactory>
 
 #include "messagepartthemes/default/defaultrenderer.h"
 
-#include "bodypartformatterfactorysingleton.h"
+#include "messageviewer_debug.h"
 
 using namespace MessageViewer;
 
@@ -64,13 +65,7 @@ bool EmptySource::htmlLoadExternal() const
     return false;
 }
 
-bool EmptySource::showSignatureDetails() const
-{
-    return false;
-}
-
-void EmptySource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode,
-                              const QList<MimeTreeParser::Util::HtmlMode> &availableModes)
+void EmptySource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode, const QList<MimeTreeParser::Util::HtmlMode> &availableModes)
 {
     Q_UNUSED(mode);
     Q_UNUSED(availableModes);
@@ -86,11 +81,6 @@ void EmptySource::setAllowDecryption(bool allowDecryption)
     d->mAllowDecryption = allowDecryption;
 }
 
-int EmptySource::levelQuote() const
-{
-    return 1;
-}
-
 const QTextCodec *EmptySource::overrideCodec()
 {
     return nullptr;
@@ -102,17 +92,17 @@ QString EmptySource::createMessageHeader(KMime::Message *message)
     return QString(); //do nothing
 }
 
-const MimeTreeParser::AttachmentStrategy *EmptySource::attachmentStrategy()
+const AttachmentStrategy *EmptySource::attachmentStrategy() const
 {
-    return MimeTreeParser::AttachmentStrategy::smart();
+    return AttachmentStrategy::smart();
 }
 
-MimeTreeParser::HtmlWriter *EmptySource::htmlWriter()
+HtmlWriter *EmptySource::htmlWriter() const
 {
     return nullptr;
 }
 
-CSSHelperBase *EmptySource::cssHelper()
+CSSHelperBase *EmptySource::cssHelper() const
 {
     return nullptr;
 }
@@ -122,6 +112,37 @@ bool EmptySource::autoImportKeys() const
     return true;
 }
 
+const MimeTreeParser::BodyPartFormatterFactory *EmptySource::bodyPartFormatterFactory()
+{
+    return MimeTreeParser::BodyPartFormatterFactory::instance();
+}
+
+void EmptySource::render(const MimeTreeParser::MessagePartPtr &msgPart, bool showOnlyOneMimePart)
+{
+    if (!htmlWriter()) {
+        qCWarning(MESSAGEVIEWER_LOG) << "no htmlWriter - skipping rendering.";
+        return;
+    }
+
+    auto renderer = DefaultRenderer(cssHelper());
+    renderer.setAttachmentStrategy(attachmentStrategy());
+    renderer.setCreateMessageHeader(std::bind(&EmptySource::createMessageHeader, this, std::placeholders::_1));
+    renderer.setHtmlLoadExternal(htmlLoadExternal());
+    renderer.setIsPrinting(isPrinting());
+    renderer.setLevelQuote(levelQuote());
+    renderer.setShowEmoticons(showEmoticons());
+    renderer.setShowExpandQuotesMark(showExpandQuotesMark());
+    renderer.setShowOnlyOneMimePart(showOnlyOneMimePart);
+    renderer.setShowSignatureDetails(showSignatureDetails());
+
+    renderer.render(msgPart, htmlWriter());
+}
+
+bool EmptySource::isPrinting() const
+{
+    return false;
+}
+
 bool EmptySource::showEmoticons() const
 {
     return false;
@@ -132,19 +153,12 @@ bool EmptySource::showExpandQuotesMark() const
     return false;
 }
 
-const MimeTreeParser::BodyPartFormatterBaseFactory *EmptySource::bodyPartFormatterFactory()
-{
-    return bodyPartFormatterBaseFactoryInstance();
-}
-
-bool EmptySource::isPrinting() const
+bool EmptySource::showSignatureDetails() const
 {
     return false;
 }
 
-MimeTreeParser::Interface::MessagePartRendererPtr EmptySource::messagePartTheme(
-    MimeTreeParser::Interface::MessagePart::Ptr msgPart)
+int EmptySource::levelQuote() const
 {
-    return MimeTreeParser::Interface::MessagePartRenderer::Ptr(new DefaultRenderer(msgPart,
-                                                                                   cssHelper()));
+    return 1;
 }
