@@ -3,7 +3,7 @@
   Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
   Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
   Copyright (c) 2009 Andras Mantia <andras@kdab.net>
-  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -48,6 +48,32 @@
 #include <QAction>
 
 namespace MessageViewer {
+class AbstractMessageLoadedHandler::Private
+{
+public:
+    Akonadi::Session *mSession = nullptr;
+};
+
+AbstractMessageLoadedHandler::AbstractMessageLoadedHandler()
+    : d(new Private)
+{
+}
+
+AbstractMessageLoadedHandler::~AbstractMessageLoadedHandler()
+{
+    delete d;
+}
+
+void AbstractMessageLoadedHandler::setSession(Akonadi::Session *session)
+{
+    d->mSession = session;
+}
+
+Akonadi::Session *AbstractMessageLoadedHandler::session() const
+{
+    return d->mSession;
+}
+
 Viewer::Viewer(QWidget *aParent, QWidget *mainWindow, KActionCollection *actionCollection)
     : QWidget(aParent)
     , d_ptr(new ViewerPrivate(this, mainWindow, actionCollection))
@@ -62,8 +88,6 @@ Viewer::~Viewer()
 
 void Viewer::initialize()
 {
-    connect(d_ptr, &ViewerPrivate::replaceMsgByUnencryptedVersion,
-            this, &Viewer::replaceMsgByUnencryptedVersion);
     connect(d_ptr, &ViewerPrivate::displayPopupMenu,
             this, &Viewer::displayPopupMenu);
     connect(d_ptr, &ViewerPrivate::popupMenu,
@@ -82,7 +106,6 @@ void Viewer::initialize()
             this, &Viewer::itemRemoved);
     connect(d_ptr, &ViewerPrivate::changeDisplayMail, this, &Viewer::slotChangeDisplayMail);
     connect(d_ptr, &ViewerPrivate::moveMessageToTrash, this, &Viewer::moveMessageToTrash);
-    connect(d_ptr, &ViewerPrivate::executeMailAction, this, &Viewer::executeMailAction);
     connect(d_ptr, &ViewerPrivate::pageIsScrolledToBottom, this, &Viewer::pageIsScrolledToBottom);
     connect(d_ptr, &ViewerPrivate::printingFinished, this, &Viewer::printingFinished);
 
@@ -117,7 +140,9 @@ void Viewer::setMessageItem(const Akonadi::Item &item, MimeTreeParser::UpdateMod
         d->setMessageItem(item, updateMode);
     } else {
         Akonadi::ItemFetchJob *job = createFetchJob(item);
-        connect(job, SIGNAL(result(KJob *)), d, SLOT(itemFetchResult(KJob *)));
+        connect(job, &Akonadi::ItemFetchJob::result, [this, d](KJob *job) {
+                d->itemFetchResult(job);
+            });
         d->displaySplashPage(i18n("Loading message..."));
     }
 }
@@ -134,8 +159,7 @@ void Viewer::setMessagePath(const QString &path)
     d->mMessagePath = path;
 }
 
-void Viewer::displaySplashPage(const QString &templateName, const QVariantHash &data,
-                               const QByteArray &domain)
+void Viewer::displaySplashPage(const QString &templateName, const QVariantHash &data, const QByteArray &domain)
 {
     Q_D(Viewer);
     d->displaySplashPage(templateName, data, domain);
@@ -341,13 +365,13 @@ void Viewer::slotFind()
     d->slotFind();
 }
 
-const MimeTreeParser::AttachmentStrategy *Viewer::attachmentStrategy() const
+const AttachmentStrategy *Viewer::attachmentStrategy() const
 {
     Q_D(const Viewer);
     return d->attachmentStrategy();
 }
 
-void Viewer::setAttachmentStrategy(const MimeTreeParser::AttachmentStrategy *strategy)
+void Viewer::setAttachmentStrategy(const AttachmentStrategy *strategy)
 {
     Q_D(Viewer);
     d->setAttachmentStrategy(strategy);
@@ -507,7 +531,8 @@ QAbstractItemModel *Viewer::messageTreeModel() const
 
 Akonadi::ItemFetchJob *Viewer::createFetchJob(const Akonadi::Item &item)
 {
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item);
+    Q_D(Viewer);
+    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, d->mSession);
     job->fetchScope().fetchAllAttributes();
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     job->fetchScope().fetchFullPayload(true);
@@ -524,6 +549,7 @@ void Viewer::addMessageLoadedHandler(AbstractMessageLoadedHandler *handler)
         return;
     }
 
+    handler->setSession(d->mSession);
     d->mMessageLoadedHandlers.insert(handler);
 }
 
@@ -631,10 +657,10 @@ void Viewer::setPluginName(const QString &pluginName)
     return d->setPluginName(pluginName);
 }
 
-void Viewer::showOpenAttachmentFolderWidget(const QUrl &url)
+void Viewer::showOpenAttachmentFolderWidget(const QList<QUrl> &urls)
 {
     Q_D(Viewer);
-    d->showOpenAttachmentFolderWidget(url);
+    d->showOpenAttachmentFolderWidget(urls);
 }
 
 QList<QAction *> Viewer::viewerPluginActionList(ViewerPluginInterface::SpecificFeatureTypes features)
