@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,6 @@ using namespace MessageViewer;
 BlockExternalResourcesUrlInterceptor::BlockExternalResourcesUrlInterceptor(QObject *parent)
     : WebEngineViewer::NetworkPluginUrlInterceptorInterface(parent)
 {
-
 }
 
 BlockExternalResourcesUrlInterceptor::~BlockExternalResourcesUrlInterceptor()
@@ -35,32 +34,33 @@ BlockExternalResourcesUrlInterceptor::~BlockExternalResourcesUrlInterceptor()
 
 bool BlockExternalResourcesUrlInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info)
 {
+    if (info.requestUrl().scheme() == QStringLiteral("data")
+        || info.requestUrl().scheme() == QStringLiteral("file"))
+        return false;
     const QWebEngineUrlRequestInfo::ResourceType resourceType = info.resourceType();
     const QWebEngineUrlRequestInfo::NavigationType navigationType = info.navigationType();
-    if (resourceType == QWebEngineUrlRequestInfo::ResourceTypeMedia ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypePing ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypePrefetch ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeFavicon ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeXhr ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeObject ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeScript ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeServiceWorker ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeSharedWorker ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeWorker ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeSubResource ||
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypePluginResource ||
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeCspReport ||
-#endif
-            resourceType == QWebEngineUrlRequestInfo::ResourceTypeUnknown) {
+    if (resourceType == QWebEngineUrlRequestInfo::ResourceTypeMedia
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypePing
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypePrefetch
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeFavicon
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeXhr
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeObject
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeScript
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeServiceWorker
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeSharedWorker
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeWorker
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeSubResource
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypePluginResource
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeCspReport
+        || resourceType == QWebEngineUrlRequestInfo::ResourceTypeUnknown) {
         return true;
     } else if (navigationType == QWebEngineUrlRequestInfo::NavigationTypeFormSubmitted) {
         Q_EMIT formSubmittedForbidden();
         return true;
-    } else if (navigationType == QWebEngineUrlRequestInfo::NavigationTypeReload ||
-               navigationType == QWebEngineUrlRequestInfo::NavigationTypeTyped ||
-               navigationType == QWebEngineUrlRequestInfo::NavigationTypeBackForward ||
-               navigationType == QWebEngineUrlRequestInfo::NavigationTypeOther) {
+    } else if (navigationType == QWebEngineUrlRequestInfo::NavigationTypeReload
+               || navigationType == QWebEngineUrlRequestInfo::NavigationTypeTyped
+               || navigationType == QWebEngineUrlRequestInfo::NavigationTypeBackForward
+               || navigationType == QWebEngineUrlRequestInfo::NavigationTypeOther) {
         return true;
     }
     return false;
