@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,6 +25,7 @@
 #include "../urlhandlermanager.h"
 #include "loadexternalreferencesurlinterceptor/loadexternalreferencesurlinterceptor.h"
 #include "blockexternalresourcesurlinterceptor/blockexternalresourcesurlinterceptor.h"
+#include "blockmailtrackingurlinterceptor/blockmailtrackingurlinterceptor.h"
 #include "cidreferencesurlinterceptor/cidreferencesurlinterceptor.h"
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineManageScript>
@@ -101,8 +102,14 @@ MailWebEngineView::MailWebEngineView(KActionCollection *ac, QWidget *parent)
         = new MessageViewer::BlockExternalResourcesUrlInterceptor(this);
     connect(blockExternalUrl, &BlockExternalResourcesUrlInterceptor::formSubmittedForbidden, this,
             &MailWebEngineView::formSubmittedForbidden);
-
     d->mNetworkAccessManager->addInterceptor(blockExternalUrl);
+
+    MessageViewer::BlockMailTrackingUrlInterceptor *blockMailTrackingUrl
+        = new MessageViewer::BlockMailTrackingUrlInterceptor(this);
+    connect(blockMailTrackingUrl, &BlockMailTrackingUrlInterceptor::mailTrackingFound, this,
+            &MailWebEngineView::mailTrackingFound);
+    d->mNetworkAccessManager->addInterceptor(blockMailTrackingUrl);
+
     setFocusPolicy(Qt::WheelFocus);
     connect(d->mPageEngine, &MailWebEnginePage::urlClicked, this, &MailWebEngineView::openUrl);
     connect(
@@ -295,15 +302,12 @@ void MailWebEngineView::setElementByIdVisible(const QString &id, bool visible)
 
 void MailWebEngineView::removeAttachmentMarking(const QString &id)
 {
-    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::removeStyleToElement(QLatin1String("*#")
-                                                                                 + id));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::removeStyleToElement(id));
 }
 
 void MailWebEngineView::markAttachment(const QString &id, const QString &style)
 {
-    //TODO verify "*#" + id
-    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::setStyleToElement(QLatin1String("*#")
-                                                                              + id, style));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::setStyleToElement(id, style));
 }
 
 void MailWebEngineView::scrollToAnchor(const QString &anchor)
