@@ -23,9 +23,7 @@
 
 #include <KMime/Message>
 
-namespace MimeTreeParser
-{
-
+namespace MimeTreeParser {
 class NodeHelperTest : public QObject
 {
     Q_OBJECT
@@ -40,6 +38,5 @@ private Q_SLOTS:
     void testCreateTempDir();
     void testFromAsString();
 };
-
 }
 #endif
