@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,12 +22,10 @@
 
 #include "webengineviewer_private_export.h"
 #include <QString>
-#include <QDateTime>
 
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class LocalDataBaseFilePrivate;
-class Addition;
+struct Addition;
 class WEBENGINEVIEWER_TESTS_EXPORT LocalDataBaseFile
 {
 public:
@@ -41,7 +39,7 @@ public:
      *
      * value
      */
-    LocalDataBaseFile(const QString &filename);
+    explicit LocalDataBaseFile(const QString &filename);
     ~LocalDataBaseFile();
 
     void close();
