@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -129,7 +129,7 @@ TestScriptWidget::TestScriptWidget(QWidget *parent)
     mScriptCombo = new QComboBox;
     vScriptLayout->addWidget(mScriptCombo);
     fillScriptCombo(mScriptCombo);
-    connect(mScriptCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(slotCurrentIndexChanged(int)));
+    connect(mScriptCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TestScriptWidget::slotCurrentIndexChanged);
 
     mScriptEdit = new QTextEdit;
     mScriptEdit->setAcceptRichText(false);
@@ -167,14 +167,14 @@ void TestScriptWidget::fillScriptCombo(QComboBox *scriptCombo)
     scriptCombo->addItem(QStringLiteral("scroll percentage"), WebEngineViewer::WebEngineScript::scrollPercentage(0));
     scriptCombo->addItem(QStringLiteral("Test is bottom"), WebEngineViewer::WebEngineScript::isScrolledToBottom());
 #if 0
-    WebEngineViewer::WebEngineScript::setElementByIdVisible(const QString & elementStr, bool visibility);
-    WebEngineViewer::WebEngineScript::setStyleToElement(const QString & elementStr, const QString & style);
+    WebEngineViewer::WebEngineScript::setElementByIdVisible(const QString &elementStr, bool visibility);
+    WebEngineViewer::WebEngineScript::setStyleToElement(const QString &elementStr, const QString &style);
     WebEngineViewer::WebEngineScript::scrollToRelativePosition(int pos);
-    WebEngineViewer::WebEngineScript::removeStyleToElement(const QString & element);
-    WebEngineViewer::WebEngineScript::injectAttachments(const QString & delayedHtml, const QString & element);
-    WebEngineViewer::WebEngineScript::toggleFullAddressList(const QString & field, const QString & html, bool doShow);
-    WebEngineViewer::WebEngineScript::replaceInnerHtml(const QString & field, const QString & html, bool doShow);
-    WebEngineViewer::WebEngineScript::updateToggleFullAddressList(const QString & field, bool doShow);
+    WebEngineViewer::WebEngineScript::removeStyleToElement(const QString &element);
+    WebEngineViewer::WebEngineScript::injectAttachments(const QString &delayedHtml, const QString &element);
+    WebEngineViewer::WebEngineScript::toggleFullAddressList(const QString &field, const QString &html, bool doShow);
+    WebEngineViewer::WebEngineScript::replaceInnerHtml(const QString &field, const QString &html, bool doShow);
+    WebEngineViewer::WebEngineScript::updateToggleFullAddressList(const QString &field, bool doShow);
 #endif
     //TODO
 }
