@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,42 +30,21 @@
 
 using namespace WebEngineViewer;
 
-class MailNetworkUrlInterceptorPluginManagerInstancePrivate
-{
-public:
-    MailNetworkUrlInterceptorPluginManagerInstancePrivate()
-        : mailNetworkUrlInterceptorPluginManager(new NetworkUrlInterceptorPluginManager)
-    {
-    }
-
-    ~MailNetworkUrlInterceptorPluginManagerInstancePrivate()
-    {
-        delete mailNetworkUrlInterceptorPluginManager;
-    }
-
-    NetworkUrlInterceptorPluginManager *mailNetworkUrlInterceptorPluginManager;
-};
-
-Q_GLOBAL_STATIC(MailNetworkUrlInterceptorPluginManagerInstancePrivate, sInstance)
-
 class MailNetworkUrlInterceptorPluginInfo
 {
 public:
     MailNetworkUrlInterceptorPluginInfo()
-        : plugin(nullptr)
     {
-
     }
 
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
     PimCommon::PluginUtilData pluginData;
-    WebEngineViewer::NetworkPluginUrlInterceptor *plugin;
-    bool isEnabled;
+    WebEngineViewer::NetworkPluginUrlInterceptor *plugin = nullptr;
+    bool isEnabled = false;
 };
 
-namespace
-{
+namespace {
 QString pluginVersion()
 {
     return QStringLiteral("1.0");
@@ -78,8 +57,8 @@ public:
     NetworkUrlInterceptorPluginManagerPrivate(NetworkUrlInterceptorPluginManager *qq)
         : q(qq)
     {
-
     }
+
     void initializePluginList();
 
     void loadPlugin(MailNetworkUrlInterceptorPluginInfo *item);
@@ -111,8 +90,8 @@ QVector<PimCommon::PluginUtilData> NetworkUrlInterceptorPluginManagerPrivate::pl
 
 void NetworkUrlInterceptorPluginManagerPrivate::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("webengineviewer"), [](const KPluginMetaData & md) {
-        return md.serviceTypes().contains(QStringLiteral("WebEngineViewer/UrlInterceptor"));
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("webengineviewer"), [](const KPluginMetaData &md) {
+        return md.serviceTypes().contains(QLatin1String("WebEngineViewer/UrlInterceptor"));
     });
 
     QVectorIterator<KPluginMetaData> i(plugins);
@@ -187,12 +166,13 @@ WebEngineViewer::NetworkPluginUrlInterceptor *NetworkUrlInterceptorPluginManager
 
 NetworkUrlInterceptorPluginManager *NetworkUrlInterceptorPluginManager::self()
 {
-    return sInstance->mailNetworkUrlInterceptorPluginManager;
+    static NetworkUrlInterceptorPluginManager s_self;
+    return &s_self;
 }
 
 NetworkUrlInterceptorPluginManager::NetworkUrlInterceptorPluginManager(QObject *parent)
-    : QObject(parent),
-      d(new NetworkUrlInterceptorPluginManagerPrivate(this))
+    : QObject(parent)
+    , d(new NetworkUrlInterceptorPluginManagerPrivate(this))
 {
     d->initializePluginList();
 }
