@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,7 +22,6 @@
 #include "webenginemanagescript.h"
 #include "webengineviewer_debug.h"
 #include "checkphishingurl/localdatabasemanager.h"
-#include "../config-webengineviewer.h"
 #include <QEvent>
 #include <QKeyEvent>
 #include <QMouseEvent>
@@ -35,16 +34,16 @@ class WebEngineViewer::WebEngineViewPrivate
 {
 public:
     WebEngineViewPrivate(WebEngineView *q)
-        : mSavedRelativePosition(-1),
-          mCurrentWidget(nullptr),
-          mWebEngineNavigatorInterceptor(nullptr),
-          mWebEngineNavigatorInterceptorView(nullptr),
-          mPhishingDatabase(nullptr),
-          mCrashCount(0),
-          q(q)
+        : mSavedRelativePosition(-1)
+        , mCurrentWidget(nullptr)
+        , mWebEngineNavigatorInterceptor(nullptr)
+        , mWebEngineNavigatorInterceptorView(nullptr)
+        , mPhishingDatabase(nullptr)
+        , mCrashCount(0)
+        , q(q)
     {
-
     }
+
     ~WebEngineViewPrivate()
     {
         delete mWebEngineNavigatorInterceptor;
@@ -56,18 +55,18 @@ public:
     void renderProcessTerminated(QWebEnginePage::RenderProcessTerminationStatus status)
     {
         switch (status) {
-            case QWebEnginePage::NormalTerminationStatus:
-                return;
+        case QWebEnginePage::NormalTerminationStatus:
+            return;
 
-            case QWebEnginePage::AbnormalTerminationStatus:
-                qCInfo(WEBENGINEVIEWER_LOG) << "WebEngine render process terminated abnormally";
-                break;
-            case QWebEnginePage::CrashedTerminationStatus:
-                qCInfo(WEBENGINEVIEWER_LOG) << "WebEngine render process crashed";
-                break;
-            case QWebEnginePage::KilledTerminationStatus:
-                qCInfo(WEBENGINEVIEWER_LOG) << "WebEngine render process killed";
-                break;
+        case QWebEnginePage::AbnormalTerminationStatus:
+            qCInfo(WEBENGINEVIEWER_LOG) << "WebEngine render process terminated abnormally";
+            break;
+        case QWebEnginePage::CrashedTerminationStatus:
+            qCInfo(WEBENGINEVIEWER_LOG) << "WebEngine render process crashed";
+            break;
+        case QWebEnginePage::KilledTerminationStatus:
+            qCInfo(WEBENGINEVIEWER_LOG) << "WebEngine render process killed";
+            break;
         }
 
         // don't get stuck in a loop if the renderer keeps crashing. Five restarts
@@ -80,35 +79,35 @@ public:
     }
 
     qreal mSavedRelativePosition;
-    QWidget *mCurrentWidget;
-    WebEngineManageScript *mManagerScript;
-    WebEngineNavigationRequestInterceptor *mWebEngineNavigatorInterceptor;
-    WebEngineView *mWebEngineNavigatorInterceptorView;
-    LocalDataBaseManager *mPhishingDatabase;
+    QWidget *mCurrentWidget = nullptr;
+    WebEngineManageScript *mManagerScript = nullptr;
+    WebEngineNavigationRequestInterceptor *mWebEngineNavigatorInterceptor = nullptr;
+    WebEngineView *mWebEngineNavigatorInterceptorView = nullptr;
+    LocalDataBaseManager *mPhishingDatabase = nullptr;
     int mCrashCount;
 
 private:
-    WebEngineView * const q;
+    WebEngineView *const q;
 };
 
 WebEngineView::WebEngineView(QWidget *parent)
-    : QWebEngineView(parent),
-      d(new WebEngineViewer::WebEngineViewPrivate(this))
+    : QWebEngineView(parent)
+    , d(new WebEngineViewer::WebEngineViewPrivate(this))
 {
     installEventFilter(this);
     d->mManagerScript = new WebEngineManageScript(this);
 
     connect(this, &QWebEngineView::renderProcessTerminated,
             this, [this](QWebEnginePage::RenderProcessTerminationStatus status) {
-                d->renderProcessTerminated(status);
-            });
+        d->renderProcessTerminated(status);
+    });
     connect(this, &QWebEngineView::loadFinished,
             this, [this]() {
-                // Reset the crash counter if we manage to actually load a page.
-                // This does not perfectly correspond to "we managed to render
-                // a page", but it's the best we have
-                d->mCrashCount = 0;
-            });
+        // Reset the crash counter if we manage to actually load a page.
+        // This does not perfectly correspond to "we managed to render
+        // a page", but it's the best we have
+        d->mCrashCount = 0;
+    });
 }
 
 WebEngineView::~WebEngineView()
@@ -126,9 +125,8 @@ void WebEngineView::initializeJQueryScript()
     QFile file(QStringLiteral(":/data/jquery.min.js"));
     file.open(QIODevice::ReadOnly);
     QString jquery = QString::fromUtf8(file.readAll());
-    jquery.append(QStringLiteral("\nvar qt = { 'jQuery': jQuery.noConflict(true) };"));
+    jquery.append(QLatin1String("\nvar qt = { 'jQuery': jQuery.noConflict(true) };"));
     d->mManagerScript->addScript(page()->profile(), jquery, QStringLiteral("jquery"), QWebEngineScript::DocumentCreation);
-
 }
 
 void WebEngineView::addScript(const QString &source, const QString &scriptName, QWebEngineScript::InjectionPoint injectionPoint)
@@ -183,7 +181,7 @@ bool WebEngineView::eventFilter(QObject *obj, QEvent *event)
     { \
         bool wasAccepted = event->isAccepted(); \
         event->setAccepted(false); \
-        f(static_cast<t*>(event)); \
+        f(static_cast<t *>(event)); \
         bool ret = event->isAccepted(); \
         event->setAccepted(wasAccepted); \
         return ret; \
@@ -256,10 +254,10 @@ qreal WebEngineView::relativePosition() const
     return d->mSavedRelativePosition;
 }
 
-LocalDataBaseManager * WebEngineView::phishingDatabase() const
+LocalDataBaseManager *WebEngineView::phishingDatabase() const
 {
     if (!d->mPhishingDatabase) {
-        d->mPhishingDatabase = new LocalDataBaseManager(const_cast<WebEngineView*>(this));
+        d->mPhishingDatabase = new LocalDataBaseManager(const_cast<WebEngineView *>(this));
         d->mPhishingDatabase->initialize();
     }
     return d->mPhishingDatabase;
