@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -48,15 +48,15 @@ public:
     WebHitTestPrivate(const QPoint &pos)
         : m_pos(pos)
     {
-
     }
+
     QPoint m_pos;
     QUrl m_pageUrl;
 };
 
 WebHitTest::WebHitTest(QWebEnginePage *page, const QPoint &pos, QObject *parent)
-    : QObject(parent),
-      d(new WebHitTestPrivate(pos))
+    : QObject(parent)
+    , d(new WebHitTestPrivate(pos))
 {
     QString source = QStringLiteral("(function() {"
                                     "var e = document.elementFromPoint(%1, %2);"
